==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/installer/messages/bg/base.php <==
<?php

return [
    '<strong>Admin</strong> Account' => '<strong>Администраторски</strong> акаунт',
    '<strong>Configuration</strong>' => '<strong>Конфигурация</strong>',
    '<strong>Congratulations</strong>. You\'re done.' => '<strong>Поздравления</strong>. Готови сте.',
    '<strong>Database</strong> Configuration' => 'Конфигурация на <strong>база от данни</strong>',
    '<strong>Example</strong> contents' => '<strong>Примерно</strong> съдържание',
    '<strong>System</strong> Check' => '<strong>Системна</strong> Проверка',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Добре дошли</strong> в HumHub <br>Кутията с инструменти за Вашата Социална Мрежа',
    'Allow access for non-registered users to public content (guest access)' => 'Разрешаване на достъп за нерегистрирани потребители до публично съдържание (достъп за гости)',
    'Allow friendships between members' => 'Позволете приятелства между членовете',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'По-долу трябва да въведете данните за връзката на вашата база от данни. Ако не сте сигурни за това, моля, свържете се със системния ви администратор.',
    'Calvin Klein – Between love and madness lies obsession.' => 'Калвин Клайн - Между любовта и лудостта се крие мания.',
    'Check again' => 'Провери отново',
    'Congratulations! Everything is ok and ready to start over!' => 'Честито! Всичко е наред и е готово да стартирате!',
    'Create Admin Account' => 'Създайте администраторски акаунт',
    'Downloading & Installing Modules...' => 'Изтегляне и инсталиране на модули...',
    'External users can register (show registration form on login)' => 'Външни потребители могат да се регистрират (покажете регистрационната форма при влизане)',
    'Here you can decide how new, unregistered users can access HumHub.' => 'Тук можете да решите как нови, нерегистрирани потребители могат да имат достъп до HumHub.',
    'Hostname' => 'Име на хост',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Име на хост на вашия сървър за база от данни MySQL (напр. localhost, ако MySQL работи на същата машина)',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub е много гъвкав и може да се регулира и / или разширява за различни приложения, благодарение на различните модули. Следващите модули са само няколко примера и тези, които сме сметнали за най-важни за избраното от вас приложение.<br><br>Винаги можете да инсталирате или премахнете модули по-късно. Можете да намерите повече налични модули след инсталирането в административната област.',
    'I want to use HumHub for:' => 'Искам да използвам HumHub за:',
    'Initializing database...' => 'Инициализиране на базата от данни...',
    'My club' => 'Моят клуб',
    'My community' => 'Моята общност',
    'My company (Social Intranet / Project management)' => 'Моята компания (социален интранет / управление на проекти)',
    'My educational institution (school, university)' => 'Моята образователна институция (училище, университет)',
    'Name of Database' => 'Име на базата от данни',
    'Name of your network' => 'Име на вашата мрежа',
    'Newly registered users have to be activated by an admin first' => 'Новорегистрираните потребители първо трябва да бъдат активирани от администратор',
    'Next' => 'Следващ',
    'Nike – Just buy it. :wink:' => 'Nike - Просто го купи. ; Намигване;',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Разбира се, новата ви социална мрежа се нуждае от име. Моля, променете името по подразбиране с такова, което ви харесва. (Например името на вашата компания, организация или клуб)',
    'Ohh, something went wrong!' => 'О, нещо се обърка!',
    'Password' => 'Парола',
    'Port' => 'Порт',
    'Recommended <strong>Modules</strong>' => 'Препоръчителни <strong>Модули</strong>',
    'Registered members can invite new users via email' => 'Регистрираните членове могат да канят нови потребители по имейл',
    'Security <strong>Settings</strong>' => '<strong>Настройки</strong> за защита',
    'Set up example content (recommended)' => 'Настройване на примерно съдържание (препоръчително)',
    'Sign in' => 'Впиши се',
    'Skip this step, I want to set up everything manually' => 'Пропусни тази стъпка, искам да настроя всичко ръчно',
    'Social Network <strong>Name</strong>' => '<strong>Име</strong> на Социалната Мрежа',
    'The installation completed successfully! Have fun with your new social network.' => 'Инсталацията завърши успешно! Забавлявайте се с новата си социална мрежа.',
    'The name of the database you want to run HumHub in.' => 'Името на базата от данни, в която искате да стартирате HumHub.',
    'This overview shows all system requirements of HumHub.' => 'Този общ преглед показва всички системни изисквания на HumHub.',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Този съветник ще инсталира и конфигурира вашата собствена инстанция на HumHub.<br><br>За да продължите, щракнете върху Напред.',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'За да избегнете празно табло след първоначалното ви влизане, HumHub може да инсталира примерно съдържание за вас. Това ще ви даде хубава обща представа за това как работи HumHub. Винаги можете да изтриете генерираното съдържание.',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'За да опростим конфигурацията, имаме предварително дефинирани настройки за най-често използваните случаи с различни опции за модули и настройки. Можете да ги коригирате по време на следващата стъпка.',
    'Username' => 'Потребителско име',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Търсим страхотни лозунги на известни марки. Може би можете да дадете някакви идеи?',
    'Welcome Space' => 'Раздел Добре Дошли',
    'Yay! I\'ve just installed HumHub :sunglasses:' => 'Еха! Току-що инсталирах HumHub; Страхотно;',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Почти сте готови. В тази стъпка трябва да попълните формуляра, за да създадете администраторски акаунт. С този акаунт можете да управлявате цялата мрежа.',
    'Your MySQL password.' => 'Вашата парола за MySQL.',
    'Your MySQL username' => 'Вашето потребителско име за MySQL',
    'Your first sample space to discover the platform.' => 'Първият ви примерен раздел за разбиране на платформата.',
    '<strong>Pretty URLs</strong> configuration' => '',
    '<strong>Scheduled jobs</strong>' => '',
    'Add following the lines to the crontab:' => '',
    'Create the database if it doesn\'t exist yet.' => '',
    'Default Language' => '',
    'Default Timezone' => '',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => '',
    'In order to activate this feature, it is necessary to edit the HumHub configuration and, potentially, the configuration of the WebServer.' => '',
    'Installation Example:' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
    'On HumHub\'s side, you will need to edit the configuration file <code>{configFile}</code> and add the following block:' => '',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => '',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => '',
    'Our documentation provides a more detailed look into <a href="{link}" target="_blank">Pretty URLs</a>.' => '',
    'Per default, the HumHub URL includes an <code>index.php</code> file in the address, resulting in a URL that looks like "<a>https://example.com/index.php?r=dashboard%2Fdashboard</a>" for example. By using the Pretty URL or URL Rewriting feature, it is possible to create shorter and easier to understand URLs, such as "<a>https://example.com/dashboard</a>".' => '',
    'Registered members can invite new users via link' => '',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/installer/messages/bg/base.php <==
<?php

return [
    '<strong>Admin</strong> Account' => '<strong>Администраторски</strong> акаунт',
    '<strong>Configuration</strong>' => '<strong>Конфигурация</strong>',
    '<strong>Congratulations</strong>. You\'re done.' => '<strong>Поздравления</strong>. Готови сте.',
    '<strong>Database</strong> Configuration' => 'Конфигурация на <strong>база от данни</strong>',
    '<strong>Example</strong> contents' => '<strong>Примерно</strong> съдържание',
    '<strong>System</strong> Check' => '<strong>Системна</strong> Проверка',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Добре дошли</strong> в HumHub <br>Кутията с инструменти за Вашата Социална Мрежа',
    'Allow access for non-registered users to public content (guest access)' => 'Разрешаване на достъп за нерегистрирани потребители до публично съдържание (достъп за гости)',
    'Allow friendships between members' => 'Позволете приятелства между членовете',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'По-долу трябва да въведете данните за връзката на вашата база от данни. Ако не сте сигурни за това, моля, свържете се със системния ви администратор.',
    'Calvin Klein – Between love and madness lies obsession.' => 'Калвин Клайн - Между любовта и лудостта се крие мания.',
    'Check again' => 'Провери отново',
    'Congratulations! Everything is ok and ready to start over!' => 'Честито! Всичко е наред и е готово да стартирате!',
    'Create Admin Account' => 'Създайте администраторски акаунт',
    'Downloading & Installing Modules...' => 'Изтегляне и инсталиране на модули...',
    'External users can register (show registration form on login)' => 'Външни потребители могат да се регистрират (покажете регистрационната форма при влизане)',
    'Here you can decide how new, unregistered users can access HumHub.' => 'Тук можете да решите как нови, нерегистрирани потребители могат да имат достъп до HumHub.',
    'Hostname' => 'Име на хост',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Име на хост на вашия сървър за база от данни MySQL (напр. localhost, ако MySQL работи на същата машина)',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub е много гъвкав и може да се регулира и / или разширява за различни приложения, благодарение на различните модули. Следващите модули са само няколко примера и тези, които сме сметнали за най-важни за избраното от вас приложение.<br><br>Винаги можете да инсталирате или премахнете модули по-късно. Можете да намерите повече налични модули след инсталирането в административната област.',
    'I want to use HumHub for:' => 'Искам да използвам HumHub за:',
    'Initializing database...' => 'Инициализиране на базата от данни...',
    'My club' => 'Моят клуб',
    'My community' => 'Моята общност',
    'My company (Social Intranet / Project management)' => 'Моята компания (социален интранет / управление на проекти)',
    'My educational institution (school, university)' => 'Моята образователна институция (училище, университет)',
    'Name of Database' => 'Име на базата от данни',
    'Name of your network' => 'Име на вашата мрежа',
    'Newly registered users have to be activated by an admin first' => 'Новорегистрираните потребители първо трябва да бъдат активирани от администратор',
    'Next' => 'Следващ',
    'Nike – Just buy it. :wink:' => 'Nike - Просто го купи. ; Намигване;',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Разбира се, новата ви социална мрежа се нуждае от име. Моля, променете името по подразбиране с такова, което ви харесва. (Например името на вашата компания, организация или клуб)',
    'Ohh, something went wrong!' => 'О, нещо се обърка!',
    'Password' => 'Парола',
    'Port' => 'Порт',
    'Recommended <strong>Modules</strong>' => 'Препоръчителни <strong>Модули</strong>',
    'Registered members can invite new users via email' => 'Регистрираните членове могат да канят нови потребители по имейл',
    'Security <strong>Settings</strong>' => '<strong>Настройки</strong> за защита',
    'Set up example content (recommended)' => 'Настройване на примерно съдържание (препоръчително)',
    'Sign in' => 'Впиши се',
    'Skip this step, I want to set up everything manually' => 'Пропусни тази стъпка, искам да настроя всичко ръчно',
    'Social Network <strong>Name</strong>' => '<strong>Име</strong> на Социалната Мрежа',
    'The installation completed successfully! Have fun with your new social network.' => 'Инсталацията завърши успешно! Забавлявайте се с новата си социална мрежа.',
    'The name of the database you want to run HumHub in.' => 'Името на базата от данни, в която искате да стартирате HumHub.',
    'This overview shows all system requirements of HumHub.' => 'Този общ преглед показва всички системни изисквания на HumHub.',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Този съветник ще инсталира и конфигурира вашата собствена инстанция на HumHub.<br><br>За да продължите, щракнете върху Напред.',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'За да избегнете празно табло след първоначалното ви влизане, HumHub може да инсталира примерно съдържание за вас. Това ще ви даде хубава обща представа за това как работи HumHub. Винаги можете да изтриете генерираното съдържание.',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'За да опростим конфигурацията, имаме предварително дефинирани настройки за най-често използваните случаи с различни опции за модули и настройки. Можете да ги коригирате по време на следващата стъпка.',
    'Username' => 'Потребителско име',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Търсим страхотни лозунги на известни марки. Може би можете да дадете някакви идеи?',
    'Welcome Space' => 'Раздел Добре Дошли',
    'Yay! I\'ve just installed HumHub :sunglasses:' => 'Еха! Току-що инсталирах HumHub; Страхотно;',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Почти сте готови. В тази стъпка трябва да попълните формуляра, за да създадете администраторски акаунт. С този акаунт можете да управлявате цялата мрежа.',
    'Your MySQL password.' => 'Вашата парола за MySQL.',
    'Your MySQL username' => 'Вашето потребителско име за MySQL',
    'Your first sample space to discover the platform.' => 'Първият ви примерен раздел за разбиране на платформата.',
    '<strong>Apache</strong> web server detected.' => '',
    '<strong>Nginx</strong> web server detected.' => '',
    '<strong>Pretty URLs</strong>' => '',
    '<strong>Scheduled jobs</strong>' => '',
    'Add following the lines to the crontab:' => '',
    'Create the database if it doesn\'t exist yet.' => '',
    'Default Language' => '',
    'Default Timezone' => '',
    'Ensure the following rule is present in your configuration: <strong>try_files $uri $uri/ /index.php?$args;</strong>.' => '',
    'For more information on this topic, please refer to our <a href="{link}" target="_blank">documentation</a>.' => '',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => '',
    'In the installation folder, locate the <strong>.env.example</strong> file and copy its contents into the <strong>.env</strong> file. Next, find the <strong>Pretty URLs</strong> block and uncomment it by removing the <strong>#</strong> symbol.' => '',
    'Installation Example:' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
    'Make sure that the following file is writable: thi' => '',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => '',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => '',
    'Pretty URLs may not work correctly.' => '',
    'Pretty URLs should work correctly.' => '',
    'Registered members can invite new users via link' => '',
    'The <strong>.htaccess</strong> file is in place.' => '',
    'The <strong>.htaccess</strong> file is not in place. In the installation folder, locate the <strong>.htaccess.dist</strong> file and rename it to <strong>.htaccess</strong>.' => '',
    'The <strong>mod_rewrite</strong> module is active.' => '',
    'The <strong>mod_rewrite</strong> module is not enabled.' => '',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => '',
    'Unable to automatically detect your web server type. Please ensure URL rewriting is configured.' => '',
];
